#
# Random Cottage Placement
# CvRandomCottagePlacementEventManager
# 

from CvPythonExtensions import *

import CvUtil
import CvEventManager
import sys
import PyHelpers
import CvConfigParser
import math
import time
			
gc = CyGlobalContext()	

PyPlayer = PyHelpers.PyPlayer
PyGame = PyHelpers.PyGame()

localText = CyTranslator()

# The base chance that cottages could spawn in the wild or near city controlled
# spaces. 
# Default value is 5
g_iBaseCottageSpawnChance = 5

# Enables or disables the random placement of cottages through out the map 
# outside of all civilization bountries#
# Default value is true
g_bWildCottagePlacement = true

# Enables or disables the random placement of cottages near city controlled 
# spaces
# Default value is true
g_bCityCottagePlacement = true

# Enables or disables the tech requirement for placing cottages near city 
# controlled spaces.
# Default value is true
g_bCityCottagePlacementTechRequired = true

# Required tech for placing cottages near city controlled spaces.
# Default value is 25 'TECH_POTTERY'
g_iCityCottagePlacementRequiredTech = 25

# Enables or disables the ability for city unhappiness to affect the placement 
# of cottages near city controlled spaces. The cottage spawn chance gets small 
# bumps from higher city unhappiness.
# Default value is true
g_bCityHappinessAffectsCottagePlacement = true

# Enables or disables the ability for city bad health to affect the placement 
# of cottages near city controlled spaces. The cottage spawn chance gets small 
# bumps from poorer city health.
# Default value is true
g_bCityHealthAffectsCottagePlacement = true

# Enables or disables the removal of population points for every cottage placed 
# near a city controlled space
# Default value is true
g_bCottagePlacementAffectCitySize = true

# The minimum size that a city has to be before cottages can spawn near its 
# controlled space.
# Default value is 3
g_iMinimumCottageHostCitySize = 3
	

def loadConfigurationData():
	global g_iBaseCottageSpawnChance
	global g_bWildCottagePlacement
	global g_bCityCottagePlacement
	global g_bCityCottagePlacementTechRequired
	global g_iCityCottagePlacementRequiredTech
	global g_bCityHappinessAffectsCottagePlacement
	global g_bCityHealthAffectsCottagePlacement
	global g_bCottagePlacementAffectCitySize
	global g_iMinimumCottageHostCitySize

		
	config = CvConfigParser.CvConfigParser("Random Cottage Placement Config.ini")

	if(config != None):
		g_iBaseCottageSpawnChance = config.getint("Random Cottage Placement", "Base Cottage Spawn Chance", 5)
		g_bWildCottagePlacement = config.getboolean("Random Cottage Placement", "Wild Cottage Placement", true)
		g_bCityCottagePlacement = config.getboolean("Random Cottage Placement", "City Cottage Placemente", true)
		g_bCityCottagePlacementTechRequired = config.getboolean("Random Cottage Placement", "City Cottage Placement Tech Required", true)
		g_iCityCottagePlacementRequiredTech = config.getint("Random Cottage Placement", "City Cottage Placement Required Tech", 25)
		g_bCityHappinessAffectsCottagePlacement = config.getboolean("Random Cottage Placement", "City Happiness Affects Cottage Placement", true)
		g_bCityHealthAffectsCottagePlacement = config.getboolean("Random Cottage Placement", "City Health Affects Cottage Placement", true)
		g_bCottagePlacementAffectCitySize = config.getboolean("Random Cottage Placement", "Cottage Placement Affect City Size", true)
		g_iMinimumCottageHostCitySize = config.getint("Random Cottage Placement", "Minimum Cottage Host City Size", 3)

 	gc.getGame().setBaseCottageSpawnChance(g_iBaseCottageSpawnChance);
 	gc.getGame().setWildCottagePlacement(g_bWildCottagePlacement);
 	gc.getGame().setCityCottagePlacement(g_bCityCottagePlacement);
 	gc.getGame().setCityCottagePlacementTechRequired(g_iBaseCottageSpawnChance);
 	gc.getGame().setCityCottagePlacementRequiredTech(g_iCityCottagePlacementRequiredTech);
 	gc.getGame().setCityHappinessAffectsCottagePlacement(g_bCityHappinessAffectsCottagePlacement);
 	gc.getGame().setCityHealthAffectsCottagePlacement(g_bCityHealthAffectsCottagePlacement);
 	gc.getGame().setCottagePlacementAffectCitySize(g_bCottagePlacementAffectCitySize);
 	gc.getGame().setMinimumCottageHostCitySize(g_iMinimumCottageHostCitySize);

	
	
class CvRandomCottagePlacementEventManager:
	
	def __init__(self, eventManager):

		eventManager.addEventHandler("GameStart", self.onGameStart)
		eventManager.addEventHandler("windowActivation", self.onWindowActivation)
		eventManager.addEventHandler("mouseEvent", self.onMouseEvent)

		loadConfigurationData()

	def onMouseEvent(self, argsList):
		eventType,mx,my,px,py,interfaceConsumed,screens = argsList
		
	def onWindowActivation(self, argsList):
		'Called when the game window activates or deactivates'
		bActive = argsList[0]
		
		if(bActive):
			loadConfigurationData()	
	
		
	def onGameStart(self, argsList):
		loadConfigurationData()
